__author__ = """Iñigo Martinez"""
__email__ = "inigomlap@gmail.com"
__version__ = "0.1.0"


def main():
    """Entry point for the application script"""
    print("Call your main application code here")
